==> neuropythy-0.9.5.tar.gz: neuropythy-0.9.5/neuropythy/util/__init__.py <==
####################################################################################################
# neuropythy/util/__init__.py
# This file defines the general tools that are available as part of neuropythy.

from .core     import (ObjectWithMetaData, normalize, denormalize,
                       to_hemi_str, to_affine, simplex_averaging_matrix, simplex_summation_matrix,
                       is_dataframe, to_dataframe, dataframe_select, dataframe_except,
                       is_image, is_image_header, curry,
                       numel, rows, part, hstack, vstack, repmat, replace_close, chop,
                       flatter, flattest, is_tuple, is_list, is_set,
                       plus, cplus, minus, cminus, times, ctimes, 
                       inv, zinv, divide, cdivide, zdivide, czdivide, power, cpower, inner,
                       sine, cosine, tangent, cotangent, secant, cosecant,
                       arcsine, arccosine, arctangent,
                       library_path, address_data, is_address, address_interpolate,
                       AutoDict, auto_dict, curve_spline, curve_intersection, close_curves,
                       is_curve_spline, to_curve_spline, CurveSpline,
                       DataStruct, data_struct, tmpdir, dirpath_to_list, apply_affine)
from .conf     import (config, to_credentials, detect_credentials, load_credentials)
from .filemap  import (FileMap, file_map, is_file_map, pseudo_path, is_pseudo_path, to_pseudo_path,
                       osf_crawl, url_download)
from .labels   import (label_colors, is_label_index, label_index, label_indices, to_label_index)

==> neuropythy-0.10.3.tar.gz: neuropythy-0.10.3/neuropythy/util/__init__.py <==
####################################################################################################
# neuropythy/util/__init__.py
# This file defines the general tools that are available as part of neuropythy.

from .core     import (ObjectWithMetaData, normalize, denormalize,
                       to_hemi_str, to_affine, simplex_averaging_matrix, simplex_summation_matrix,
                       is_dataframe, to_dataframe, dataframe_select, dataframe_except,
                       is_image, is_image_header, curry,
                       numel, rows, part, hstack, vstack, repmat, replace_close, chop,
                       flatter, flattest, is_tuple, is_list, is_set,
                       plus, cplus, minus, cminus, times, ctimes, 
                       inv, zinv, divide, cdivide, zdivide, czdivide, power, cpower, inner,
                       sine, cosine, tangent, cotangent, secant, cosecant,
                       arcsine, arccosine, arctangent,
                       naneq, nanne, nanlt, nanle, nangt, nange,
                       library_path, address_data, is_address, address_interpolate,
                       AutoDict, auto_dict, curve_spline, curve_intersection, close_curves,
                       is_curve_spline, to_curve_spline, CurveSpline,
                       DataStruct, data_struct, tmpdir, dirpath_to_list, apply_affine, try_until)
from .conf     import (config, to_credentials, detect_credentials, load_credentials)
from .filemap  import (FileMap, file_map, is_file_map, pseudo_path, is_pseudo_path, to_pseudo_path,
                       osf_crawl, url_download)
from .labels   import (label_colors, is_label_index, label_index, label_indices, to_label_index)
